# Partition Sets

Partition Sets provides a consolidated set of recipes gently provided by other
users over the years and under the MIT license. I modified these slightly so
that they now equally work under python2 and python3. All bugs are mine ;-)

You may find it useful for tasks involving small sets and also multi sets/bags.

[![license](https://img.shields.io/github/license/sthagen/partitionsets?style=flat)](https://github.com/sthagen/partitionsets/blob/default/LICENSE)

[![version](https://img.shields.io/pypi/v/partitionsets.svg?style=flat)](https://pypi.python.org/pypi/partitionsets/)
[![downloads](https://img.shields.io/pypi/dm/partitionsets.svg?style=flat)](https://pypi.python.org/pypi/partitionsets/)
[![wheel](https://img.shields.io/pypi/wheel/partitionsets.svg?style=flat)](https://pypi.python.org/pypi/partitionsets/)
[![supported-versions](https://img.shields.io/pypi/pyversions/partitionsets.svg?style=flat)](https://pypi.python.org/pypi/partitionsets/)
[![supported-implementations](https://img.shields.io/pypi/implementation/partitionsets.svg?style=flat)](https://pypi.python.org/pypi/partitionsets/)

## Thanks also to

This package merely wraps up several recipes (and comments) gently provided
under the MIT license through several people. Those I noticed have been noted below.
Any missing names are my fault. In case I get notified, I will try
to update, add or remove items in below lists accordingly.

### Partition

* Anton Vredegoor
* Chris Haulk

### OrderedSet

* Don Sawatzky
* Emil Wall
* Raymond Hettinger

### Misc

* Nathan Hurst send feedback and a patch for version 0.1.1 - thanks


For further reference please see the comments of the module files.

## References

[A0001101]: "Bell or exponential numbers: ways of placing n labeled balls
	into n indistinguishable boxes." at http://oeis.org/A000110

[BellNumber]: Wikipedia entry Bell_number
	at https://en.wikipedia.org/wiki/Bell_number

[OEIS]: Wikipedia entry On-Line_Encyclopedia_of_Integer_Sequences at
	https://en.wikipedia.org/wiki/On-Line_Encyclopedia_of_Integer_Sequences

[Flake8]: https://pypi.org/project/flake8/

[OrdSetImplPy]: https://code.activestate.com/recipes/576694/ (mixed with
	the simplified code from Don Sawatzky's comment, which is sufficient
	for this task)

[PartImplPy]: https://code.activestate.com/recipes/577211/ (r1)

[PartOfASet_WP]: Wikipedia entry Partition_of_a_set at
	https://en.wikipedia.org/wiki/Partition_of_a_set

[PyLint]: https://pypi.org/project/pylint/
